@@ -1,5 +1,5 @@
 """(fan) speed commands."""
-from typing import Any, Mapping, Union
+from typing import Any, Mapping
 
 from ..events import FanSpeedEvent
 from ..message import HandlingResult
@@ -41,7 +41,7 @@ class SetFanSpeed(SetCommand):
     get_command = GetFanSpeed
 
     def __init__(
-        self, speed: Union[str, int, FanSpeedLevel], **kwargs: Mapping[str, Any]
+        self, speed: str | int | FanSpeedLevel, **kwargs: Mapping[str, Any]
     ) -> None:
         if isinstance(speed, str):
             speed = FanSpeedLevel.get(speed)
