@@ -1,5 +1,3 @@
-from typing import Union
-
 import pytest
 
 from deebot_client.commands import FanSpeedLevel, GetFanSpeed, SetFanSpeed
@@ -8,11 +6,11 @@ from tests.commands import assert_command_requested
 from tests.helpers import get_request_json, verify_DisplayNameEnum_unique
 
 
-def test_FanSpeedLevel_unique():
+def test_FanSpeedLevel_unique() -> None:
     verify_DisplayNameEnum_unique(FanSpeedLevel)
 
 
-def test_GetFanSpeed_requested():
+def test_GetFanSpeed_requested() -> None:
     json = get_request_json({"speed": 2})
     assert_command_requested(GetFanSpeed(), json, FanSpeedEvent("max+"))
 
@@ -20,7 +18,7 @@ def test_GetFanSpeed_requested():
 @pytest.mark.parametrize(
     "value, expected", [("quiet", 1000), ("max+", 2), (0, 0), (FanSpeedLevel.MAX, 1)]
 )
-def test_SetFanSpeed(value: Union[str, int, FanSpeedLevel], expected: int):
+def test_SetFanSpeed(value: str | int | FanSpeedLevel, expected: int) -> None:
 
     command = SetFanSpeed(value)
     assert command.name == "setSpeed"
